# ProductRatePlanObjectNSFieldsBillingPeriodNS

Billing period associated with the corresponding item in NetSuite. Only available if you have installed the [Zuora Connector for NetSuite](https://www.zuora.com/connect/app/?appId=265). 

## Enum

* `MONTHLY` (value: `'Monthly'`)

* `QUARTERLY` (value: `'Quarterly'`)

* `ANNUAL` (value: `'Annual'`)

* `SEMI_MINUS_ANNUAL` (value: `'Semi-Annual'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


